# CSS Overflow Module Level 4

## Editor’s Draft, 1 January 1970

Specification Metadata

This version:
  https://drafts.csswg.org/css-overflow-4/
Latest published version:
  https://www.w3.org/TR/css-overflow-4/
Previous Versions:
  https://www.w3.org/TR/css-overflow-3/
Editors:
  L. David Baron (Mozilla)
  Florian Rivoal (On behalf of Bloomberg)
Issue Tracking:
  GitHub Issues
Suggest an Edit for this Spec:
  GitHub Editor

Copyright © 1970 W3C® (MIT, ERCIM, Keio, Beihang). W3C liability, trademark and permissive document license rules apply.

## Abstract

This module contains the features of CSS relating to new mechanisms of overflow handling in visual media (e.g., screen or paper). In interactive media, it describes features that allow the overflow from a fixed size container to be handled by pagination (displaying one page at a time). It also describes features, applying to all visual media, that allow the contents of an element to be spread across multiple fragments, allowing the contents to flow across multiple regions or to have different styles for different fragments.

CSS is a language for describing the rendering of structured documents (such as HTML and XML) on screen, on paper, etc.

## Status of this document

This is a public copy of the editors’ draft. It is provided for discussion only and may change at any moment. Its publication here does not imply endorsement of its contents by W3C. Don’t cite this document other than as work in progress.

GitHub Issues are preferred for discussion of this specification. When filing an issue, please put the text “css-overflow” in the title, preferably like this: “[css-overflow] …summary of comment…”. All issues and comments are archived, and there is also a historical archive.

This document was produced by the CSS Working Group.

This document was produced by a group operating under the W3C Patent Policy. W3C maintains a public list of any patent disclosures made in connection with the deliverables of the group; that page also includes instructions for disclosing a patent. An individual who has actual knowledge of a patent which the individual believes contains Essential Claim(s) must disclose the information in accordance with section 6 of the W3C Patent Policy.

This document is governed by the 1 March 2019 W3C Process Document.

## 1. Introduction

Note: At the time of writing, [CSS-OVERFLOW-3] is not completely finalized yet. To avoid accidental divergences and maintenance overhead, This specification is written as a delta specification over css-overflow Level 3. Once the level 3 specification is final, its content will be integrated into this specification, which will then replace it. Until then, this specification only contains additions and extensions to level 3.

In CSS Level 1 [CSS1], placing more content than would fit inside an element with a specified size was generally an authoring error. Doing so caused the content to extend outside the bounds of the element, which would likely cause that content to overlap with other elements.

CSS Level 2 [CSS21] introduced the overflow property, which allows authors to have overflow be handled by scrolling, which means it is no longer an authoring error. It also allows authors to specify that overflow is handled by clipping, which makes sense when the author’s intent is that the content not be shown. This was further refined in the CSS Overflow Module Level 3 [CSS-OVERFLOW-3].

However, scrolling is not the only way to present large amounts of content, and may even not be the optimal way. After all, the codex replaced the scroll as the common format for large written works because of its advantages.

This specification introduces a mechanism for Web pages to specify that an element of a page should handle overflow through pagination rather than through scrolling.

This specification also extends the concept of overflow in another direction. Instead of requiring that authors specify a single area into which the content of an element must flow, this specification allows authors to specify multiple fragments, each with their own dimensions and styles, so that the content of the element can flow from one to the next, using as many as needed to place the content without overflowing.

In both of these cases, implementations must break the content in the block-progression dimension. Implementations must do this is described in the CSS Fragmentation Module [CSS3-BREAK].

The definition of the text-overflow property in this module supersedes the one in [CSS-UI-3] and [CSS-OVERFLOW-3].

## 2. Types of overflow

copy level 3 content when final

## 3. Overflow properties

copy level 3 content when final

## 4. Reserving space for the scrollbar: the scrollbar-gutter property

The space between the inner border edge and the outer padding edge which user agents may reserve to display the scrollbar is called the scrollbar gutter.

The scrollbar-gutter property gives control to the author over the presence of scrollbar gutters separately from the ability to control the presence of scrollbars provided by the overflow property.

Name: | scrollbar-gutter
Value: | auto | [ stable | always ] && both? && force?
Initial: | auto
Applies to: | all elements
Inherited: | yes
Percentages: | n/a
Computed value: | specified keyword(s)
Canonical order: | per grammar
Animation type: | discrete

This property affects the presence of scrollbar gutters placed at the inline start edge or inline end edge of the box.

The presence of a scrollbar gutter at the block start edge and block end edge of the box cannot be controlled in this level, and is determined the same way as the presence of scrollbar gutters placed at the inline start edge or inline end edge of the box when scrollbar-gutter is auto.

Scrollbars which by default are placed over the content box and do not cause scrollbar gutters to be created are called overlay scrollbars. Such scrollbars are usually partially transparent, revealing the content behind them if any. Their appearance and size may vary based on whether and how the user is interacting with them.

Scrollbars which are always placed in a scrollbar gutter, consuming space when present, are called classic scrollbars. Such scrollbars are usually opaque.

Whether classic scrollbars or overlay scrollbars are used is UA defined.

The appearance and size of the scrollbar is UA defined.

Whether scrollbars appear on the start or end edge of the box is UA defined.

For classic scrollbars, the width of the scrollbar gutter is the same as the width of the scrollbar. For overlay scrollbars, the width of the scrollbar gutter is UA defined. However, it must not be 0, and it must not change based on user interactions with the page or the scrollbar even if the scrollbar itself changes. Also, it must be the same for all elements in the page.

The values of this property have the following meaning:

auto
  Classic scrollbars consume space by creating a scrollbar gutter when overflow is scroll, or when overflow is auto and the box is overflowing. Overlay scrollbars do not consume space.
stable
  The scrollbar gutter is present when overflow is scroll or auto and the scrollbar is a classic scrollbar even if the box is not overflowing, but not when the scrollbar is an overlay scrollbar.
always
  The scrollbar gutter is always present when overflow is scroll or auto, regardless of the type of scrollbar or of whether the box is overflowing.
both
  If a scrollbar gutter would be present on one of the inline start edge or the inline end edge of the box, another scrollbar gutter must be present on the opposite edge as well.
force
  When the force keyword is present stable and always take effect when overflow is visible, hidden or clip in addition auto or scroll. This does not cause a scrollbar to be displayed, only a scrollbar gutter.

When the scrollbar gutter is present but the scrollbar is not, or the scrollbar is transparent or otherwise does not fully obscure the scrollbar gutter, the background of the scrollbar gutter must be painted as an extension of the padding.

Note: The following table summarizes the interaction of overflow and scrollbar-gutter, showing in which case space is reserved for the scrollbar gutter. In this table, “G” represents cases where space is reserved for the scrollbar gutter, “f?” cases where space is reserved for the scrollbar gutter if force was specified, and empty cells cases where the no space is reserved.

|  | Classic scrollbars | Overlay scrollbars
overflow | scrollbar-gutter | Overflowing | Not overflowing | Overflowing | Not overflowing
--- | --- | --- | --- | --- | ---
scroll | auto | G | G |  |
stable | G | G |  |
always | G | G | G | G
auto | auto | G |  |  |
stable | G | G |  |
always | G | G | G | G
visible, hidden, clip | auto |  |  |  |
stable | f? | f? |  |
always | f? | f? | f? | f?

## 5. Overflow Ellipsis: the text-overflow property

Name: | text-overflow
Value: | [ clip | ellipsis | <string> | fade | <fade()> ]{1,2}
Initial: | clip
Applies to: | block containers
Inherited: | no
Percentages: | refer to the width of the line box
Computed value: | as specified, with lengths made absolute
Canonical order: | per grammar
Animation type: | by computed value type

This property specifies rendering when inline content overflows its line box edge in the inline progression direction of its block container element ("the block") that has overflow other than visible.

Even though this property is not inherited, annonymous block container boxes generated to establish the line box’s inline formatting context (see ) are ignored, and the value of the property that applies is the one on the non annomymous box. This can be seen in the “nested paragraph” part of example 7: even though the word “NESTED” is wrapped in an annoymous block container whose text-overflow property has the intial value, it is ellipsed.

Text can overflow for example when it is prevented from wrapping (e.g. due to `white-space: nowrap` or a single word is too long to fit). Values have the following meanings:

clip
  Clip inline content that overflows its block container element. Characters may be only partially rendered.
ellipsis
  Render an ellipsis character (U+2026) to represent clipped inline content. Implementations may substitute a more language, script, or writing-mode appropriate ellipsis character, or three dots "..." if the ellipsis character is unavailable.
<string>
  Render the given string to represent clipped inline content. The given string is treated as an independent paragraph for bidi purposes.
fade( <length> | <percentage> )
  Clip inline content that overflows its line box. Characters may be only partially rendered. In addition, the UA must apply a fade out effect near the edge of the line box, reaching complete transparency at the edge.

  Do we need to define the way the fade out is calculated so that the fading is identical across browsers? It should probably be something like mask-image: linear-gradient(to right, rgba(0,0,0,1), rgba(0,0,0,0)), except applied to the relevant portion of the line only.

  The argument determines the distance over which the fade effect is applied. The <percentage> is resolved against the width of the line box. Values lower than 0 are clipped to 0. Values greater than the width of the line box are clipped to the width of the line box.

  If the line box is too short to display the fade effect at the desired length, should we drop the effect, or shrink the distance it is applied over until it fits, or clip the end of the fade?

  How should we deal with things overflowing out of the line box, or overlapping onto it? Should fade apply to the logical content of the line, or to the physical area of the line box, or the intersection of both?

fade
  Same as fade(), but the distance over which the fading effect is applied is determined by the UA. 1em is suggested as a reasonable value.

The term "character" is used in this property definition for better readability and means "grapheme cluster" [UAX29] for implementation purposes.

If there is one value, it applies only to the end line box edge. If there are two values, the first value applies to the line-left edge, and the second value applies to the line-right edge. The terms end, line-left and line-right are defined in [CSS-WRITING-MODES-3].

Note: the use of line-left and line-right rather than start and end when there are two values is intentional, to facilitate the use of directional characters such as arrows.

For the ellipsis and string values, implementations must hide characters and atomic inline-level elements at the applicable edge(s) of the line as necessary to fit the ellipsis/string, and place the ellipsis/string immediately adjacent to the applicable edge(s) of the remaining inline content. The first character or atomic inline-level element on a line must be clipped rather than ellipsed.

### Bidi ellipsis examples

These examples demonstrate which characters get hidden to make room for the ellipsis in a bidi situation: those visually at the edge of the line.

Sample CSS:

    div {
      font-family: monospace;
      white-space: pre;
      overflow: hidden;
      width: 9ch;
      text-overflow: ellipsis;
    }

Sample HTML fragments, renderings, and your browser:

HTML | Reference rendering | Your Browser
--- | --- | ---
`<div>שלום 123456</div>` | 123456 ם… | שלום 123456
`<div dir=rtl>שלום 123456</div>` | …456 שלום | שלום 123456

### ellipsing details

- Ellipsing only affects rendering and must not affect layout nor dispatching of pointer events: The UA should dispatch any pointer event on the ellipsis to the elided element, as if text-overflow had been none.
- The ellipsis is styled and baseline-aligned according to the block.
- Ellipsing occurs after relative positioning and other graphical transformations.
- If there is insufficient space for the ellipsis, then clip the rendering of the ellipsis itself (on the same side that neutral characters on the line would have otherwise been clipped with the text-overflow:clip value).

### user interaction with ellipsis

- When the user is interacting with content (e.g. editing, selecting, scrolling), the user agent may treat ellipsis, string values, fade or fade() as text-overflow:clip.
- Selecting the ellipsis should select the ellipsed text. If all of the ellipsed text is selected, UAs should show selection of the ellipsis. Behavior of partially-selected ellipsed text is up to the UA.

### text-overflow examples

These examples demonstrate setting the text-overflow of a block container element that has text which overflows its dimensions:

sample CSS for a div:

    div {
      font-family: Helvetica, sans-serif;
      line-height: 1.1;
      width: 3.1em;
      border: solid .1em black;
      padding: 0.2em; margin:1em 0;
    }

sample HTML fragments, renderings, and your browser:

HTML | sample rendering | your browser
--- | --- | ---
    <div>
    CSS IS AWESOME, YES
    </div>
|  | CSS IS AWESOME, YES
    <div style="text-overflow:clip; overflow:hidden">
    CSS IS AWESOME, YES
    </div>
|  | CSS IS AWESOME, YES
    <div style="text-overflow:ellipsis; overflow:hidden">
    CSS IS AWESOME, YES
    </div>
|  | CSS IS AWESOME, YES
    <div style="text-overflow:ellipsis; overflow:hidden">
    NESTED
     <p>PARAGRAPH</p>
    WON’T ELLIPSE.
    </div>
|  | NESTED PARAGRAPH WON’T ELLIPSE.
    <div style="text-overflow:fade; overflow:hidden">
    CSS IS AWESOME, YES
    </div>
|  | CSS IS AWESOME, YES

Note: the side of the line that the ellipsis is placed depends on the direction of the block. E.g. an overflow hidden right-to-left (`direction: rtl`) block clips inline content on the left side, thus would place a text-overflow ellipsis on the left to represent that clipped content.

insert RTL example diagram here to illustrate note.

### ellipsis interaction with scrolling interfaces

This section applies to elements with text-overflow other than text-overflow:clip (non-clip text-overflow) and overflow:scroll.

When an element with non-clip text-overflow has overflow of scroll in the inline progression dimension of the text, and the browser provides a mechanism for scrolling (e.g. a scrollbar on the element, or a touch interface to swipe-scroll, etc.), there are additional implementation details that provide a better user experience:

When an element is scrolled (e.g. by the user, DOM manipulation), more of the element’s content is shown. The value of text-overflow should not affect whether more of the element’s content is shown or not. If a non-clip text-overflow is set, then as more content is scrolled into view, implementations should show whatever additional content fits, only truncating content which would otherwise be clipped (or is necessary to make room for the ellipsis/string), until the element is scrolled far enough to display the edge of the content at which point that content should be displayed rather than an ellipsis/string.

This example uses text-overflow on an element with overflow scroll to demonstrate the above described behavior.

sample CSS:

    div.crawlbar {
      text-overflow: ellipsis;
      height: 2em;
      overflow: scroll;
      white-space: nowrap;
      width: 15em;
      border:1em solid black;
    }

sample HTML fragment:

    <div class="crawlbar">
    CSS is awesome, especially when you can scroll
    to see extra text instead of just
    having it overlap other text by default.
    </div>

demonstration of sample CSS and HTML:

CSS is awesome, especially when you can scroll to see extra text instead of just having it overlap other text by default.

As some content is scrolled into view, it is likely that other content may scroll out of view on the other side. If that content’s block container element is the same that’s doing the scrolling, and the computed value of text-overflow has two values, with the value applying to the start edge being a non-clip value, then implementations must render an ellipsis/string in place of the clipped content, with the same details as described in the value definition above, except that the ellipsis/string is drawn in the start (rather than end) of the block’s direction (per the direction property).

While the content is being scrolled, implementations may adjust their rendering of ellipses/strings (e.g. align to the box edges rather than line edges).

Same as previous example except with `text-overflow: ellipsis ellipsis`, demonstrated:
CSS is awesome, especially when you can scroll to see extra text instead of just having it overlap other text by default.

If there is insufficient space for both start and end ellipses/strings, then only the end ellipsis/string should be rendered.

## 6. Fragmentation of overflow

The continue property gives authors the ability to request that content that does not fit inside an element be fragmented (in the sense of [CSS3-BREAK]), and provides alternatives for where the remaining content should continue.

Notably, this property explains traditional pagination, and extends it further.

Name: | continue
Value: | auto | overflow | paginate | fragments | discard
Initial: | auto
Applies to: | block containers [CSS21], flex containers [CSS3-FLEXBOX], and grid containers [CSS3-GRID-LAYOUT]
Inherited: | no
Percentages: | N/A
Computed value: | see below
Canonical order: | per grammar
Animation type: | discrete

The naming of this property and its values is preliminary. This was initially proposed as "fragmentation: auto | none | break | clone | page" in https://lists.w3.org/Archives/Public/www-style/2015Jan/0357.html, and there is not yet wide agreement as to which naming is better.

This property is meant to generalize and replace region-fragment. Once it is sufficiently stable in this specification, region-fragment should be removed from the regions specification in favor of this.

Note: continue: fragments replaces "overflow:fragments" from earlier versions of this specification, while continue: paginate replaces "overflow: paged-x | paged-y | paged-x-controls | paged-y-controls"

auto
  auto may only occur as a computed value if the element is a CSS Region other than the last one in a region chain. Content that doesn’t fit is pushed to the next region of the chain.

  In all other cases, auto computes to one of the other values.

overflow
  Content that doesn’t fit overflows, according to the overflow property
discard
  Content that doesn’t fit is discarded at a fragmentation break

  Note: generalized from region-fragment: break; on the last region of a region chain

  When the element isn’t a fragmentation container already, should this work by turning it directly into one, or by creating a fragment box inside it like fragments does?

paginate
  Content that doesn’t fit paginates. This creates a paginated view inside the element similar to the way that 'overflow: scroll' creates a scrollable view.

  See paginated overflow

  Note: Print is effectively "continue: paginate" on the root.

fragments
  content that doesn’t fit causes the element to copy itself and continue laying out.

  See fragment overflow.

The computed value of the continue for a given element or pseudo element is determined as follow:

1. On elements or pseudo elements with layout containment (see [CSS-CONTAIN-1]), if the specified value is auto or fragments then the computed value is overflow.
2. Otherwise, if the specified value is auto
   1. On a CSS Region other than the last one in a region chain, the computed value is auto
   2. On a page the computed value is paginate
   3. On a fragment box the computed value is fragments
   4. Otherwise, the computed value is overflow
3. Otherwise, if the specified value is fragments
   1. On a page the computed value is paginate
   2. Otherwise, the computed value is the specified value
4. In all other cases, the computed value is the specified value

If we introduce a pseudo element that can select columns in a multicol, we would need to specify that auto computes to auto on it, or introduce a new value and have auto compute to that (but what would that value compute to on things that aren’t columns?).

Note: For background discussions leading to this property, see these threads: discussion of overflow, overflow-x, overflow-y and overflow-style and proposal for a fragmentation property

## 7. Paginated overflow

This section introduces and defines the meaning of the paginate value of the continue property.

Write this section

Pages should be possible to style with @page rules. How does that work for nested pages?

Should traditional pagination (e.g. when printing) be expressed through some magic in the computed value of auto, or by inserting this in the UA stylesheet:

    @media (overflow-block: paged), (overflow-block: optional-paged) {
      :root {
        continue: paginate;
      }
    }

Traditional pagination (e.g. when printing) assumes that :root is contained in the page box, rather than having the page box be a pseudo element child of :root. Can we work around that using something similar to fragment boxes? Or maybe by having a fragment box (reproducing :root) inside a page box inside :root?

How does the page box model work when it is a child of a regular css box?

The initial proposal in [CSS3GCPM] and implementation from Opera used 4 values instead of paginate: "paged-x | paged-y | paged-x-controls | paged-y-controls". Should this property also include these values, or are they better handled as separate properties? (e.g.: "pagination-layout: auto | horizontal | vertical", "pagination-controls: auto | none")

Ability to display N pages at once rather than just one page at once? Could this be a value of "pagination-layout", such as: "pagination-layout: horizontal 2;"

Brad Kemper has proposed a model for combining pagination and fragment overflow, which also deals with displaying multiple pages. http://www.w3.org/mid/FF1704C5-D5C1-4D6F-A99D-0DD094036685@gmail.com

The current implementation of paginated overflow uses the overflow/overflow-x/overflow-y properties rather than the overflow-style property as proposed in the [CSS3GCPM] draft (which also matches the [CSS3-MARQUEE] proposal). or the continue property as described here.

## 8. Fragment overflow

This section introduces and defines the meaning of the fragments value of the continue property.

When the computed value of continue for an element is fragments, and implementations would otherwise have created a box for the element, then implementations must create a sequence of fragment boxes for that element. (It is possible for an element with continue: fragments to generate only one fragment box. However, if an element’s computed continue is not fragments, then its box is not a fragment box.) Every fragment box is a fragmentation container, and any overflow that would cause that fragmentation container to fragment causes another fragment box created as a next sibling of the previous one. Or is it as though it’s a next sibling of the element? Need to figure out exactly how this interacts with other box-level fixup. Additionally, if the fragment box is also a multi-column box (as defined in [CSS3COL] though it defines multi-column container) any content that would lead to the creation of overflow columns [CSS3COL] instead is flown into an additional fragment box. However, fragment boxes may themselves be broken (due to fragmentation in a fragmentation context outside of them, such as pages, columns, or other fragment boxes); such breaking leads to fragments of the same fragment box rather than multiple fragment boxes. (This matters because fragment boxes may be styled by their index; such breaking leads to multiple fragments of a fragment box with a single index. This design choice is so that breaking a fragment box across pages does not break the association of indices to particular pieces of content.) Should a forced break that breaks to an outer fragmentation context cause a new fragment of a single fragment box or a new fragment box? Should we find a term other than fragment box here to make this a little less confusing?

What if we want to be able to style the pieces of an element split within another type of fragmentation context? These rules prevent ever using ::nth-fragment() for that, despite that the name seems the most logical name for such a feature.

    <!DOCTYPE HTML><title>Breaking content into
      equal-sized cards</title>
    <style>
      .in-cards {
        continue: fragments;

        width: 13em;
        height: 8em;

        padding: 4px;
        border: medium solid blue;
        margin: 6px;

        font: medium/1.3 Times New
          Roman, Times, serif;
      }
    </style>
    <div class="in-cards">
      In this example, the text in the div
      is broken into a series of cards.
      These cards all have the same style.
      The presence of enough content to
      overflow one of the cards causes
      another one to be created.  The second
      card is created just like it’s the
      next sibling of the first.
    </div>
| In this example, the text in the div is broken into a series of cards. These cards all have the same style. The presence of enough content to overflow one of the cards causes another one to be created. The second card is created just like it’s the next sibling of the first.

We should specify that continue: fragments does not apply to at least some table parts, and perhaps other elements as well. We need to determine exactly which ones.

This specification needs to say which type of fragmentation context is created so that it’s clear which values of the break-* properties cause breaks within this context. We probably want break-*: region to apply.

This specification needs a processing model that will apply in cases where the layout containing the fragments has characteristics that use the intrinsic size of the fragments to change the amount of space available for them, such as [CSS3-GRID-LAYOUT]. There has already been some work on such a processing model in [CSS3-REGIONS], and the work done on a model there, and the editors of that specification, should inform what happens in this specification.

### 8.1. Fragment styling

#### 8.1.1. The ::nth-fragment() pseudo-element

The ::nth-fragment() pseudo-element is a pseudo-element that describes some of the fragment boxes generated by an element. The argument to the pseudo-element takes the same syntax as the argument to the :nth-child() pseudo-class defined in [SELECT], and has the same meaning except that the number is relative to fragment boxes generated by the element instead of siblings of the element.

Selectors that allow addressing fragments by counting from the end rather than the start are intentionally not provided. Such selectors would interfere with determining the number of fragments.

Depending on future discussions, this ::nth-fragment(an+b) syntax may be replaced with the new ::fragment:nth(an+b) syntax.

#### 8.1.2. Styling of fragments

Should this apply to continue:fragments only, or also to continue:paginate? (If it applies, then stricter property restrictions would be needed for continue:paginate.)

In the absence of rules with ::nth-fragment() pseudo-elements, the computed style for each fragment box is the computed style for the element for which the fragment box was created. However, the style for a fragment box is also influenced by rules whose selector’s subject [SELECT] has an ::nth-fragment() pseudo-element, if the 1-based number of the fragment box matches that ::nth-fragment() pseudo-element and the selector (excluding the ::nth-fragment() pseudo-element) matches the element generating the fragments.

When determining the style of the fragment box, these rules that match the fragment pseudo-element cascade together with the rules that match the element, with the fragment pseudo-element adding the specificity of a pseudo-class to the specificity calculation. Does this need to be specified in the cascading module as well?

    <!DOCTYPE HTML><style>
      .bouncy-columns {
        continue: fragments;
        width: 6em;
        height: 10em;
        float: left;
        margin: 1em;
        font: medium/1.25 Times New
          Roman, Times, serif;
      }
      .bouncy-columns::nth-fragment(1) {
        background: aqua; color: black;
        transform: rotate(-3deg);
      }
      .bouncy-columns::nth-fragment(2) {
        background: yellow; color: black;
        transform: rotate(3deg);
      }
    </style>
    <div class="bouncy-columns">
      ...
    </div>
| In this example, the text in the div is broken into a series of columns. The author probably intended the text to fill two columns. But if it happens to fill three columns, the third column is still created. It just doesn’t have any fragment-specific styling because the author didn’t give it any.

Styling an ::nth-fragment() pseudo-element with the continue property does take effect; if a fragment box has a computed value of continue other than fragments then that fragment box is the last fragment. However, overriding continue on the first fragment does not cause the fragment box not to exist; whether there are fragment boxes at all is determined by the computed value of overflow for the element.

Styling an ::nth-fragment() pseudo-element with the content property has no effect; the computed value of content for the fragment box remains the same as the computed value of content for the element.

Specifying display: none for a fragment box causes the fragment box with that index not to be generated. However, in terms of the indices used for matching ::nth-fragment() pseudo-elements of later fragment boxes, it still counts as though it was generated. However, since it is not generated, it does not contain any content.

Specifying other values of display, position, or float is permitted, but is not allowed to change the inner display type. (Since continue only applies to block containers, flex containers, and grid containers). Need to specify exactly how this works

To match the model for other pseudo-elements where the pseudo-elements live inside their corresponding element, declarations in ::nth-fragment() pseudo-elements override declarations in rules without the pseudo-element. The relative priority within such declarations is determined by normal cascading order (see [CSS21]).

Styles specified on ::nth-fragment() pseudo-elements do affect inheritance to content within the fragment box. In other words, the content within the fragment box must inherit from the fragment box’s style (i.e., the pseudo-element style) rather than directly from the element. This means that elements split between fragment boxes may have different styles for different parts of the element.

This inheritance rule allows specifying styles indirectly (by using explicit inherit or using default inheritance on properties that don’t apply to ::first-letter) that can’t be specified directly (based on the rules in the next section). This is a problem. The restrictions that apply to styling inside fragments should also apply to inheritance from fragments.

    <!DOCTYPE HTML><style>
      .article {
        continue: fragments;
      }
      .article::nth-fragment(1) {
        font-size: 1.5em;
        margin-bottom: 1em;
        height: 4em;
      }
      .article::nth-fragment(2) {
        margin-left: 5em;
        margin-right: 2em;
      }
    </style>
    <div class="article">
      The <code>font-size</code> property...
    </div>
| The `font-size` property specified on the fragment is inherited into the descendants of the fragment. This means that inherited properties can be used reliably on a fragment, as in this example.

#### 8.1.3. Styling inside fragments

Should this apply to continue:fragments only, or also to continue:paginate?

The ::nth-fragment() pseudo-element can also be used to style content inside of a fragment box. Unlike the ::first-line and ::first-letter pseudo-elements, the ::nth-fragment() pseudo-element can be applied to parts of the selector other than the subject: in particular, it can match ancestors of the subject. However, the only CSS properties applied by rules with such selectors are those that apply to the ::first-letter pseudo-element.

To be more precise, when a rule’s selector has ::nth-fragment() pseudo-elements attached to parts of the selector other than the subject, the declarations in that rule apply to a fragment (or pseudo-element thereof) when:

1. the declarations are for properties that apply to the ::first-letter pseudo-element,
2. the declarations would apply to that fragment (or pseudo-element thereof) had those ::nth-fragment() pseudo-elements been removed, with a particular association between each sequence of simple selectors and the element it matched, and
3. for each removed ::nth-fragment() pseudo-element, the fragment lives within a fragment box of the element associated in that association with the selector that the pseudo-element was attached to, and whose index matches the pseudo-element.

    <!DOCTYPE HTML><style>
      .dark-columns {
        continue: fragments;
        width: 6em;
        height: 10em;
        float: left;
        margin-right: 1em;
        font: medium/1.25 Times New
          Roman, Times, serif;
      }
      .dark-columns::nth-fragment(1) {
        background: aqua; color: black;
      }
      .dark-columns::nth-fragment(1) :link {
        color: blue;
      }
      .dark-columns::nth-fragment(1) :visited {
        color: purple;
      }
      .dark-columns::nth-fragment(2) {
        background: navy; color: white;
      }
      .dark-columns::nth-fragment(2) :link {
        color: aqua;
      }
      .dark-columns::nth-fragment(2) :visited {
        color: fuchsia;
      }
    </style>
    <div class="dark-columns">
      ...
    </div>
| In this example, the text flows from one light-colored fragment into another dark-colored fragment. We therefore want different styles for hyperlinks in the different fragments.

### 8.2. The max-lines property

Authors may wish to style the opening lines of an element with different styles by putting those opening lines in a separate fragment. However, since it may be difficult to predict the exact height occupied by those lines in order to restrict the first fragment to that height, this specification introduces a max-lines property that forces a fragment to break after a specified number of lines. This forces a break after the given number of lines contained within the element or its descendants, as long as those lines are in the same block formatting context.

Name: | max-lines
Value: | none | <integer>
Initial: | none
Applies to: | fragment boxes
Inherited: | no
Percentages: | N/A
Computed value: | the keyword none or an integer
Canonical order: | per grammar
Animatable: | as integer
Animation type: | by computed value type

none

  Breaks occur only as specified elsewhere.

<integer>

  In addition to any breaks specified elsewhere, a break is forced before any line that would exceed the given number of lines being placed inside the element (excluding lines that are in a different block formatting context from the block formatting context to which an unstyled child of the element would belong).

  If there are multiple boundaries between this line and the previous, where exactly (in terms of element boundaries) is the break forced?

  Only positive integers are accepted. Zero or negative integers are a parse error.

Should this apply to fragment overflow only, or also to pagination? Given what we’re doing with the continue property, it should actually apply to any fragmentainer.

having max-lines do nothing on regular elements is not ideal. When applied to non fragmentainers, it should probably cause continue to compute to discard so that you only need to reach for one property rather than 2 to get that effect.

    <!DOCTYPE HTML><style>
      .article {
        continue: fragments;
      }
      .article::first-letter {
        font-size: 2em;
        line-height: 0.9;
      }
      .article::nth-fragment(1) {
        font-size: 1.5em;
        max-lines: 3;
      }
      .article::nth-fragment(2) {
        column-count: 2;
      }
    </style>
    <div class="article">
      ...
    </div>
| The max-lines property allows authors to use a larger font for the first few lines of an article. Without the max-lines property, authors might have to use the height property instead, but that would leave a slight gap if the author miscalculated how much height a given number of lines would occupy (which might be particularly hard if the author didn’t know what text would be filling the space, exactly what font would be used, or exactly which platform’s font rendering would be used to display the font).

## 9. Privacy and Security Considerations

This specification introduces no new security considerations.

The TAG has developed a self-review questionnaire to help editors and Working Groups evaluate the risks introduced by their specifications. Answers are provided below.

Does this specification deal with personally-identifiable information?
  No.
Does this specification deal with high-value data?
  No.
Does this specification introduce new state for an origin that persists across browsing sessions?
  No.
Does this specification expose persistent, cross-origin state to the web?
  No.
Does this specification expose any other data to an origin that it doesn’t currently have access to?
  No.
Does this specification enable new script execution/loading mechanisms?
  No.
Does this specification allow an origin access to a user’s location?
  No.
Does this specification allow an origin access to sensors on a user’s device?
  No.
Does this specification allow an origin access to aspects of a user’s local computing environment?
  No.
Does this specification allow an origin access to other devices?
  No.
Does this specification allow an origin some measure of control over a user agent’s native UI?
  No
Does this specification expose temporary identifiers to the web?
  No.
Does this specification distinguish between behavior in first-party and third-party contexts?
  No.
How should this specification work in the context of a user agent’s "incognito" mode?
  No difference in behavior is needed.
Does this specification persist data to a user’s local device?
  No.
Does this specification have a "Security Considerations" and "Privacy Considerations" section?
  Yes, this is the section you are currently reading.
Does this specification allow downgrading default security characteristics?
  No.

## Changes

### Changes Since Level 3

The following changes were made to this specification since the CSS Overflow Module Level 3:

- The Fragmentation of overflow, Paginated overflow, and Fragment overflow sections and subsections have been removed form Level 3 and moved to Level 4.
- The scrollbar-gutter property has been added.

## Acknowledgments

Thanks especially to the feedback from Rossen Atanassov, Bert Bos, Tantek Çelik, John Daggett, fantasai, Daniel Glazman, Vincent Hardy, Håkon Wium Lie, Peter Linss, Robert O’Callahan, Florian Rivoal, Alan Stearns, Steve Zilles, and all the rest of the www-style community.

## Conformance

### Document conventions

Conformance requirements are expressed with a combination of descriptive assertions and RFC 2119 terminology. The key words “MUST”, “MUST NOT”, “REQUIRED”, “SHALL”, “SHALL NOT”, “SHOULD”, “SHOULD NOT”, “RECOMMENDED”, “MAY”, and “OPTIONAL” in the normative parts of this document are to be interpreted as described in RFC 2119. However, for readability, these words do not appear in all uppercase letters in this specification.

All of the text of this specification is normative except sections explicitly marked as non-normative, examples, and notes. [RFC2119]

Examples in this specification are introduced with the words “for example” or are set apart from the normative text with `class="example"`, like this:

This is an example of an informative example.

Informative notes begin with the word “Note” and are set apart from the normative text with `class="note"`, like this:

Note, this is an informative note.

Advisements are normative sections styled to evoke special attention and are set apart from other normative text with `<strong class="advisement">`, like this: UAs MUST provide an accessible alternative.

### Conformance classes

Conformance to this specification is defined for three conformance classes:

style sheet
  A CSS style sheet.
renderer
  A UA that interprets the semantics of a style sheet and renders documents that use them.
authoring tool
  A UA that writes a style sheet.

A style sheet is conformant to this specification if all of its statements that use syntax defined in this module are valid according to the generic CSS grammar and the individual grammars of each feature defined in this module.

A renderer is conformant to this specification if, in addition to interpreting the style sheet as defined by the appropriate specifications, it supports all the features defined by this specification by parsing them correctly and rendering the document accordingly. However, the inability of a UA to correctly render a document due to limitations of the device does not make the UA non-conformant. (For example, a UA is not required to render color on a monochrome monitor.)

An authoring tool is conformant to this specification if it writes style sheets that are syntactically correct according to the generic CSS grammar and the individual grammars of each feature in this module, and meet all other conformance requirements of style sheets as described in this module.

### Requirements for Responsible Implementation of CSS

The following sections define several conformance requirements for implementing CSS responsibly, in a way that promotes interoperability in the present and future.

#### Partial Implementations

So that authors can exploit the forward-compatible parsing rules to assign fallback values, CSS renderers must treat as invalid (and ignore as appropriate) any at-rules, properties, property values, keywords, and other syntactic constructs for which they have no usable level of support. In particular, user agents must not selectively ignore unsupported property values and honor supported values in a single multi-value property declaration: if any value is considered invalid (as unsupported values must be), CSS requires that the entire declaration be ignored.

#### Implementations of Unstable and Proprietary Features

To avoid clashes with future stable CSS features, the CSSWG recommends following best practices for the implementation of unstable features and proprietary extensions to CSS.

#### Implementations of CR-level Features

Once a specification reaches the Candidate Recommendation stage, implementers should release an unprefixed implementation of any CR-level feature they can demonstrate to be correctly implemented according to spec, and should avoid exposing a prefixed variant of that feature.

To establish and maintain the interoperability of CSS across implementations, the CSS Working Group requests that non-experimental CSS renderers submit an implementation report (and, if necessary, the testcases used for that implementation report) to the W3C before releasing an unprefixed implementation of any CSS features. Testcases submitted to W3C are subject to review and correction by the CSS Working Group.

Further information on submitting testcases and implementation reports can be found from on the CSS Working Group’s website at http://www.w3.org/Style/CSS/Test/. Questions should be directed to the public-css-testsuite@w3.org mailing list.

Support: Android Browser2.1+Baidu Browser7.12+Blackberry Browser7+Chrome4+Chrome for Android74+Edge12+Firefox7+Firefox for Android66+IE6+IE Mobile10+KaiOS Browser2.5+Opera11+Opera MiniAllOpera Mobile12.1+QQ Browser1.2+Safari3.1+Samsung Internet4+UC Browser for Android11.8+iOS Safari3.2+

Source: caniuse.com as of 2019-06-04

## Index

### Terms defined by this specification

- always, in §4
- auto
  - value for continue, in §6
  - value for scrollbar-gutter, in §4
- both, in §4
- classic scrollbars, in §4
- clip, in §5
- continue, in §6
- discard, in §6
- ellipsis, in §5
- fade, in §5
- fade(), in §5
- force, in §4
- fragment box, in §8
- fragments, in §6
- <integer>, in §8.2
- max-lines, in §8.2
- none, in §8.2
- ::nth-fragment(), in §8.1.1
- overflow, in §6
- overlay scrollbars, in §4
- paginate, in §6
- scrollbar gutter, in §4
- scrollbar-gutter, in §4
- stable, in §4
- text-overflow, in §5

https://drafts.csswg.org/css-break-4/#fragmentation-container Referenced in:

- 6. Fragmentation of overflow

https://drafts.csswg.org/css-cascade-4/#valdef-all-inherit Referenced in:

- 8.1.2. Styling of fragments

https://drafts.csswg.org/css-contain-1/#layout-containment Referenced in:

- 6. Fragmentation of overflow

https://drafts.csswg.org/css-content-3/#propdef-content Referenced in:

- 8.1.2. Styling of fragments (2)

https://drafts.csswg.org/css-display-3/#propdef-display Referenced in:

- 8.1.2. Styling of fragments (2)

https://drafts.csswg.org/css-display-3/#inline-formatting-context Referenced in:

- 5. Overflow Ellipsis: the text-overflow property

https://drafts.csswg.org/css-display-3/#inner-display-type Referenced in:

- 8.1.2. Styling of fragments

https://drafts.fxtf.org/css-masking-1/#propdef-mask-image Referenced in:

- 5. Overflow Ellipsis: the text-overflow property

https://drafts.csswg.org/css-overflow-3/#valdef-overflow-auto Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4) (5)

https://drafts.csswg.org/css-overflow-3/#valdef-overflow-clip Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2)

https://drafts.csswg.org/css-overflow-3/#valdef-overflow-hidden Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2)

https://drafts.csswg.org/css-overflow-3/#propdef-overflow Referenced in:

- 1. Introduction
- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4) (5) (6) (7) (8)
- 5. Overflow Ellipsis: the text-overflow property
- 6. Fragmentation of overflow

https://drafts.csswg.org/css-overflow-3/#valdef-overflow-scroll Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4) (5)

https://drafts.csswg.org/css-overflow-3/#valdef-overflow-visible Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2)
- 5. Overflow Ellipsis: the text-overflow property

https://drafts.csswg.org/css-position-3/#propdef-position Referenced in:

- 8.1.2. Styling of fragments

https://drafts.csswg.org/css-pseudo-4/#selectordef-first-letter Referenced in:

- 8.1.2. Styling of fragments
- 8.1.3. Styling inside fragments (2) (3)

https://drafts.csswg.org/css-pseudo-4/#selectordef-first-line Referenced in:

- 8.1.3. Styling inside fragments

https://drafts.csswg.org/css-values-3/#integer-value Referenced in:

- 8.2. The max-lines property (2)

https://drafts.csswg.org/css-values-3/#length-value Referenced in:

- 5. Overflow Ellipsis: the text-overflow property

https://drafts.csswg.org/css-values-3/#percentage-value Referenced in:

- 5. Overflow Ellipsis: the text-overflow property (2)

https://drafts.csswg.org/css-values-3/#string-value Referenced in:

- 5. Overflow Ellipsis: the text-overflow property (2)

https://drafts.csswg.org/css-values-4/#comb-all Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2)

https://drafts.csswg.org/css-values-4/#mult-opt Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2)

https://drafts.csswg.org/css-values-4/#mult-num-range Referenced in:

- 5. Overflow Ellipsis: the text-overflow property

https://drafts.csswg.org/css-values-4/#comb-one Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2)
- 5. Overflow Ellipsis: the text-overflow property (2) (3) (4)
- 6. Fragmentation of overflow (2) (3) (4)
- 8.2. The max-lines property

https://drafts.csswg.org/css-writing-modes-3/#propdef-direction Referenced in:

- user interaction with ellipsis

https://drafts.csswg.org/css-writing-modes-3/#physical-left Referenced in:

- user interaction with ellipsis (2)

https://drafts.csswg.org/css-writing-modes-4/#block-end Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property

https://drafts.csswg.org/css-writing-modes-4/#block-start Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property

https://drafts.csswg.org/css-writing-modes-4/#end Referenced in:

- 5. Overflow Ellipsis: the text-overflow property (2) (3)
- ellipsis interaction with scrolling interfaces

https://drafts.csswg.org/css-writing-modes-4/#inline-end Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2)

https://drafts.csswg.org/css-writing-modes-4/#inline-start Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2)

https://drafts.csswg.org/css-writing-modes-4/#line-left Referenced in:

- 5. Overflow Ellipsis: the text-overflow property (2) (3)

https://drafts.csswg.org/css-writing-modes-4/#line-right Referenced in:

- 5. Overflow Ellipsis: the text-overflow property (2) (3)

https://drafts.csswg.org/css-writing-modes-4/#start Referenced in:

- 5. Overflow Ellipsis: the text-overflow property
- ellipsis interaction with scrolling interfaces

https://drafts.csswg.org/css2/visuren.html#propdef-float Referenced in:

- 8.1.2. Styling of fragments

https://drafts.csswg.org/css2/visudet.html#propdef-height Referenced in:

- 8.2. The max-lines property

https://drafts.csswg.org/css-regions-1/#css-region Referenced in:

- 6. Fragmentation of overflow (2)

https://drafts.csswg.org/css-regions-1/#region-chain Referenced in:

- 6. Fragmentation of overflow (2)

https://drafts.csswg.org/css-regions-1/#propdef-region-fragment Referenced in:

- 6. Fragmentation of overflow (2)

https://drafts.csswg.org/css-multicol-1/#overflow-columns Referenced in:

- 8. Fragment overflow

### Terms defined by reference

- [css-break-4] defines the following terms:
  - fragmentation container
- [css-cascade-4] defines the following terms:
  - inherit
- [CSS-CONTAIN-1] defines the following terms:
  - layout containment
- [css-content-3] defines the following terms:
  - content
- [css-display-3] defines the following terms:
  - display
  - inline formatting context
  - inner display type
- [css-masking-1] defines the following terms:
  - mask-image
- [CSS-OVERFLOW-3] defines the following terms:
  - auto
  - clip
  - hidden
  - overflow
  - scroll
  - visible
- [css-position-3] defines the following terms:
  - position
- [css-pseudo-4] defines the following terms:
  - ::first-letter
  - ::first-line
- [css-values-3] defines the following terms:
  - <integer>
  - <length>
  - <percentage>
  - <string>
- [css-values-4] defines the following terms:
  - &&
  - ?
  - {a,b}
  - |
- [CSS-WRITING-MODES-3] defines the following terms:
  - direction
  - left
- [css-writing-modes-4] defines the following terms:
  - block end
  - block start
  - end
  - inline end
  - inline start
  - line-left
  - line-right
  - start
- [CSS21] defines the following terms:
  - float
  - height
- [CSS3-REGIONS] defines the following terms:
  - css region
  - region chain
  - region-fragment
- [CSS3COL] defines the following terms:
  - overflow columns

## References

### Normative References

[CSS-BREAK-4]
  Rossen Atanassov; Elika Etemad. CSS Fragmentation Module Level 4. 18 December 2018. WD. URL: https://www.w3.org/TR/css-break-4/
[CSS-CASCADE-4]
  Elika Etemad; Tab Atkins Jr.. CSS Cascading and Inheritance Level 4. 28 August 2018. CR. URL: https://www.w3.org/TR/css-cascade-4/
[CSS-CONTAIN-1]
  Tab Atkins Jr.; Florian Rivoal. CSS Containment Module Level 1. 30 April 2019. CR. URL: https://www.w3.org/TR/css-contain-1/
[CSS-CONTENT-3]
  Elika Etemad; Dave Cramer. CSS Generated Content Module Level 3. 2 June 2016. WD. URL: https://www.w3.org/TR/css-content-3/
[CSS-DISPLAY-3]
  Tab Atkins Jr.; Elika Etemad. CSS Display Module Level 3. 28 August 2018. CR. URL: https://www.w3.org/TR/css-display-3/
[CSS-MASKING-1]
  Dirk Schulze; Brian Birtles; Tab Atkins Jr.. CSS Masking Module Level 1. 26 August 2014. CR. URL: https://www.w3.org/TR/css-masking-1/
[CSS-OVERFLOW-3]
  David Baron; Elika Etemad; Florian Rivoal. CSS Overflow Module Level 3. 31 July 2018. WD. URL: https://www.w3.org/TR/css-overflow-3/
[CSS-POSITION-3]
  Rossen Atanassov; Arron Eicholz. CSS Positioned Layout Module Level 3. 17 May 2016. WD. URL: https://www.w3.org/TR/css-position-3/
[CSS-PSEUDO-4]
  Daniel Glazman; Elika Etemad; Alan Stearns. CSS Pseudo-Elements Module Level 4. 25 February 2019. WD. URL: https://www.w3.org/TR/css-pseudo-4/
[CSS-VALUES-3]
  Tab Atkins Jr.; Elika Etemad. CSS Values and Units Module Level 3. 31 January 2019. CR. URL: https://www.w3.org/TR/css-values-3/
[CSS-VALUES-4]
  Tab Atkins Jr.; Elika Etemad. CSS Values and Units Module Level 4. 31 January 2019. WD. URL: https://www.w3.org/TR/css-values-4/
[CSS-WRITING-MODES-3]
  Elika Etemad; Koji Ishii. CSS Writing Modes Level 3. 24 May 2018. CR. URL: https://www.w3.org/TR/css-writing-modes-3/
[CSS-WRITING-MODES-4]
  Elika Etemad; Koji Ishii. CSS Writing Modes Level 4. 24 May 2018. CR. URL: https://www.w3.org/TR/css-writing-modes-4/
[CSS21]
  Bert Bos; et al. Cascading Style Sheets Level 2 Revision 1 (CSS 2.1) Specification. 7 June 2011. REC. URL: https://www.w3.org/TR/CSS2/
[CSS3-BREAK]
  Rossen Atanassov; Elika Etemad. CSS Fragmentation Module Level 3. 4 December 2018. CR. URL: https://www.w3.org/TR/css-break-3/
[CSS3-FLEXBOX]
  Tab Atkins Jr.; et al. CSS Flexible Box Layout Module Level 1. 19 November 2018. CR. URL: https://www.w3.org/TR/css-flexbox-1/
[CSS3-GRID-LAYOUT]
  Tab Atkins Jr.; Elika Etemad; Rossen Atanassov. CSS Grid Layout Module Level 1. 14 December 2017. CR. URL: https://www.w3.org/TR/css-grid-1/
[CSS3-REGIONS]
  Rossen Atanassov; Alan Stearns. CSS Regions Module Level 1. 9 October 2014. WD. URL: https://www.w3.org/TR/css-regions-1/
[CSS3COL]
  Florian Rivoal; Rachel Andrew. CSS Multi-column Layout Module Level 1. 28 May 2018. WD. URL: https://www.w3.org/TR/css-multicol-1/
[RFC2119]
  S. Bradner. Key words for use in RFCs to Indicate Requirement Levels. March 1997. Best Current Practice. URL: https://tools.ietf.org/html/rfc2119
[SELECT]
  Tantek Çelik; et al. Selectors Level 3. 6 November 2018. REC. URL: https://www.w3.org/TR/selectors-3/
[UAX29]
  Mark Davis. Unicode Text Segmentation. 15 February 2019. Unicode Standard Annex #29. URL: https://www.unicode.org/reports/tr29/tr29-35.html

### Informative References

[CSS-UI-3]
  Tantek Çelik; Florian Rivoal. CSS Basic User Interface Module Level 3 (CSS3 UI). 21 June 2018. REC. URL: https://www.w3.org/TR/css-ui-3/
[CSS1]
  Håkon Wium Lie; Bert Bos. Cascading Style Sheets, level 1. 13 September 2018. REC. URL: https://www.w3.org/TR/CSS1/
[CSS3-MARQUEE]
  Bert Bos. CSS Marquee Module Level 3. 14 October 2014. NOTE. URL: https://www.w3.org/TR/css3-marquee/
[CSS3GCPM]
  Dave Cramer. CSS Generated Content for Paged Media Module. 13 May 2014. WD. URL: https://www.w3.org/TR/css-gcpm-3/

## Property Index

Name | Value | Initial | Applies to | Inh. | %ages | Animatable | Animation type | Canonical order | Computed value
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
continue | auto | overflow | paginate | fragments | discard | auto | block containers [CSS21], flex containers [CSS3-FLEXBOX], and grid containers [CSS3-GRID-LAYOUT] | no | N/A |  | discrete | per grammar | see below
max-lines | none | <integer> | none | fragment boxes | no | N/A | as integer | by computed value type | per grammar | the keyword none or an integer
scrollbar-gutter | auto | [ stable | always ] && both? && force? | auto | all elements | yes | n/a |  | discrete | per grammar | specified keyword(s)
text-overflow | [ clip | ellipsis | <string> | fade | <fade()> ]{1,2} | clip | block containers | no | refer to the width of the line box |  | by computed value type | per grammar | as specified, with lengths made absolute

## Issues Index

copy level 3 content when final ↵
copy level 3 content when final ↵
Do we need to define the way the fade out is calculated so that the fading is identical across browsers? It should probably be something like mask-image: linear-gradient(to right, rgba(0,0,0,1), rgba(0,0,0,0)), except applied to the relevant portion of the line only. ↵
If the line box is too short to display the fade effect at the desired length, should we drop the effect, or shrink the distance it is applied over until it fits, or clip the end of the fade? ↵
How should we deal with things overflowing out of the line box, or overlapping onto it? Should fade apply to the logical content of the line, or to the physical area of the line box, or the intersection of both? ↵
insert RTL example diagram here to illustrate note. ↵
The naming of this property and its values is preliminary. This was initially proposed as "fragmentation: auto | none | break | clone | page" in https://lists.w3.org/Archives/Public/www-style/2015Jan/0357.html, and there is not yet wide agreement as to which naming is better. ↵
This property is meant to generalize and replace region-fragment. Once it is sufficiently stable in this specification, region-fragment should be removed from the regions specification in favor of this. ↵
When the element isn’t a fragmentation container already, should this work by turning it directly into one, or by creating a fragment box inside it like fragments does? ↵
If we introduce a pseudo element that can select columns in a multicol, we would need to specify that auto computes to auto on it, or introduce a new value and have auto compute to that (but what would that value compute to on things that aren’t columns?). ↵
Write this section ↵
Pages should be possible to style with @page rules. How does that work for nested pages? ↵
Should traditional pagination (e.g. when printing) be expressed through some magic in the computed value of auto, or by inserting this in the UA stylesheet:

    @media (overflow-block: paged), (overflow-block: optional-paged) {
      :root {
        continue: paginate;
      }
    }

↵
Traditional pagination (e.g. when printing) assumes that :root is contained in the page box, rather than having the page box be a pseudo element child of :root. Can we work around that using something similar to fragment boxes? Or maybe by having a fragment box (reproducing :root) inside a page box inside :root? ↵
How does the page box model work when it is a child of a regular css box? ↵
The initial proposal in [CSS3GCPM] and implementation from Opera used 4 values instead of paginate: "paged-x | paged-y | paged-x-controls | paged-y-controls". Should this property also include these values, or are they better handled as separate properties? (e.g.: "pagination-layout: auto | horizontal | vertical", "pagination-controls: auto | none") ↵
Ability to display N pages at once rather than just one page at once? Could this be a value of "pagination-layout", such as: "pagination-layout: horizontal 2;" ↵
Brad Kemper has proposed a model for combining pagination and fragment overflow, which also deals with displaying multiple pages. http://www.w3.org/mid/FF1704C5-D5C1-4D6F-A99D-0DD094036685@gmail.com ↵
The current implementation of paginated overflow uses the overflow/overflow-x/overflow-y properties rather than the overflow-style property as proposed in the [CSS3GCPM] draft (which also matches the [CSS3-MARQUEE] proposal). or the continue property as described here. ↵
Or is it as though it’s a next sibling of the element? Need to figure out exactly how this interacts with other box-level fixup. ↵
though it defines multi-column container ↵
Should a forced break that breaks to an outer fragmentation context cause a new fragment of a single fragment box or a new fragment box? ↵
Should we find a term other than fragment box here to make this a little less confusing? ↵
What if we want to be able to style the pieces of an element split within another type of fragmentation context? These rules prevent ever using ::nth-fragment() for that, despite that the name seems the most logical name for such a feature. ↵
We should specify that continue: fragments does not apply to at least some table parts, and perhaps other elements as well. We need to determine exactly which ones. ↵
This specification needs to say which type of fragmentation context is created so that it’s clear which values of the break-* properties cause breaks within this context. We probably want break-*: region to apply. ↵
This specification needs a processing model that will apply in cases where the layout containing the fragments has characteristics that use the intrinsic size of the fragments to change the amount of space available for them, such as [CSS3-GRID-LAYOUT]. There has already been some work on such a processing model in [CSS3-REGIONS], and the work done on a model there, and the editors of that specification, should inform what happens in this specification. ↵
Depending on future discussions, this ::nth-fragment(an+b) syntax may be replaced with the new ::fragment:nth(an+b) syntax. ↵
Should this apply to continue:fragments only, or also to continue:paginate? (If it applies, then stricter property restrictions would be needed for continue:paginate.) ↵
Does this need to be specified in the cascading module as well? ↵
Need to specify exactly how this works ↵
This inheritance rule allows specifying styles indirectly (by using explicit inherit or using default inheritance on properties that don’t apply to ::first-letter) that can’t be specified directly (based on the rules in the next section). This is a problem. The restrictions that apply to styling inside fragments should also apply to inheritance from fragments. ↵
Should this apply to continue:fragments only, or also to continue:paginate? ↵
If there are multiple boundaries between this line and the previous, where exactly (in terms of element boundaries) is the break forced? ↵
Should this apply to fragment overflow only, or also to pagination? Given what we’re doing with the continue property, it should actually apply to any fragmentainer. ↵
having max-lines do nothing on regular elements is not ideal. When applied to non fragmentainers, it should probably cause continue to compute to discard so that you only need to reach for one property rather than 2 to get that effect. ↵
#scrollbar-gutter Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4) (5) (6) (7) (8) (9) (10) (11) (12) (13) (14) (15) (16) (17) (18) (19) (20)

#propdef-scrollbar-gutter Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4) (5)
- Changes Since Level 3

#overlay-scrollbars Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4)

#classic-scrollbars Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4)

#valdef-scrollbar-gutter-auto Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4)

#valdef-scrollbar-gutter-stable Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4)

#valdef-scrollbar-gutter-always Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2) (3) (4)

#valdef-scrollbar-gutter-force Referenced in:

- 4. Reserving space for the scrollbar: the scrollbar-gutter property (2)

#propdef-text-overflow Referenced in:

- 1. Introduction
- 5. Overflow Ellipsis: the text-overflow property (2)
- ellipsing details
- ellipsis interaction with scrolling interfaces

#overflow-ellipsis Referenced in:

- user interaction with ellipsis

#funcdef-text-overflow-fade Referenced in:

- 5. Overflow Ellipsis: the text-overflow property (2)

#propdef-continue Referenced in:

- 6. Fragmentation of overflow (2) (3) (4)
- 7. Paginated overflow (2)
- 8. Fragment overflow (2) (3) (4) (5)
- 8.1.2. Styling of fragments (2) (3) (4)
- 8.2. The max-lines property

#valdef-continue-auto Referenced in:

- 6. Fragmentation of overflow (2) (3) (4) (5)
- 7. Paginated overflow

#valdef-continue-overflow Referenced in:

- 6. Fragmentation of overflow (2)

#valdef-continue-discard Referenced in:

- 8.2. The max-lines property

#valdef-continue-paginate Referenced in:

- 6. Fragmentation of overflow (2)
- 7. Paginated overflow (2)

#valdef-continue-fragments Referenced in:

- 6. Fragmentation of overflow (2) (3) (4)
- 8. Fragment overflow (2) (3)
- 8.1.2. Styling of fragments

#fragment-box Referenced in:

- 6. Fragmentation of overflow (2)
- 8. Fragment overflow (2) (3) (4) (5) (6)
- 8.1.1. The ::nth-fragment() pseudo-element (2)
- 8.1.2. Styling of fragments (2) (3) (4) (5) (6) (7) (8) (9) (10)
- 8.1.3. Styling inside fragments (2)

#selectordef-nth-fragment Referenced in:

- 8. Fragment overflow
- 8.1.1. The ::nth-fragment() pseudo-element
- 8.1.2. Styling of fragments (2) (3) (4) (5) (6) (7) (8) (9)
- 8.1.3. Styling inside fragments (2) (3) (4) (5)

#propdef-max-lines Referenced in:

- 8.2. The max-lines property (2)

#valdef-max-lines-none Referenced in:

- 8.2. The max-lines property